SSH: keygen (uses a randomizer) ELLIPTIC CURVES (ssh-keygen -t ecdsa -N "" -C "" -b 521 -f ECDSA_521_key) ssh-keygen -t ed25519 ssh-keygen -t ecdsa -b 521 RSA (ssh-keygen -t rsa -N "" -b 3072 -C "" -f RSA && mv RSA RSA.private && mv RSA.pub RSA.public) ssh-keygen -t rsa -b 4096 AGENT ssh-agent ADD ssh-add ECDSA_521_KEY GITLAB USAGE https://docs.gitlab.com/ee/user/ssh.html#configure-ssh-to-point-to-a-different-directory